%  xml - Constructor for an xml-object   
%   
%  CALL:   
%     obj = xml(FileName, isNameSpaceAware)   
%   
%  INPUT:   
%      FileName:   
%          string, the name of the sourcefile   
%          string, the xml string   
%          java-object, a D(ocument) (O)bject (M)odel   
%          struct, a Matlab structure   
%          isNameSpaceAware:   
%          boolean, (optional) (default == 1) use namespaces   
%   
%  OUTPUT:   
%   obj:   
%    xml-object with fields:   
%     - DOM:  <java object> the DOM object   
%     - file: <string> the name of the xml source   
%     - NS:   <java object> a hashmap with namespace definitions   
%             N.B. obj is empty when an error occurred   
%   
%  EXAMPLE:   
%   %create an xml from a sourcefile   
%   obj = xml(fullfile(pwd,'examples','books.xml'))   
%   inspect(obj)   
%   
%   %create an xml from a sourcefile   
%   obj = xml(java.io.File(fullfile(pwd,'examples','books.xml')))   
%   inspect(obj)   
%   
%   %create an xml from a Matlab structure   
%   obj = xml(dir)   
%   inspect(obj)   
%   
%   %create an xml directly from a string   
%   str = '<book category="MATHS"><title lang="en">Nonlinear Programming</title><author>Dimitri P. Bertsekas</author></book>'   
%   obj = xml(str)   
%   inspect(obj)   
%   
%   %create an xml directly from an inputstream   
%   obj = xml(java.io.FileInputStream((fullfile(pwd,'examples','books.xml'))))   
%   inspect(obj)   
%   
%  See also: xml/view, xml/inspect   
   
   
%  Modelit 2006-2014   
% Matlab release: 2012a   
% Date: 2014/10/22 17:31:02   
% Revision: 1.08   
